package MT::Plugin::StylelessImage;
use strict;
use MT;
use MT::Plugin;

use MT::Template::Context;

require MT::Plugin;

our $VERSION = 0.2;

use base qw( MT::Plugin );

@MT::Plugin::StylelessImage::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::StylelessImage({
    id => 'stylelessimage',
    key => 'StylelessImage',
    description => 'Insert Image Styleless @ WYSIWYG Editor.',
    name => 'Styleless Image',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    'version' => $VERSION,
});

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        callbacks => {
            'cms_post_save.entry'
                => \&_post_save_entry,
            'MT::App::CMS::template_source.asset_options'
                => \&_asset_options,
            'MT::App::CMS::template_source.asset_options_image'
                => \&_asset_options_image,
            'MT::App::CMS::template_source.asset_insert'
                => \&_asset_insert,
            'MT::App::CMS::template_source.edit_entry'
                => {
                handler => \&_edit_entry,
                priority => 10,
            },
        },
	    tags => {
            modifier => {
                'assetelement' => \&_assetelement,
            },
        }
   });
}

sub _assetelement {
	my($text, $arg, $ctx) = @_;
	my @args = split(/\,/,$arg);
	my $element = $args[0];
	my $class = $args[1];
	my $closer = '';
	if ($element) {
        $closer = "</$element>";
	    $element = '<' . $element;
	    if ($class) {
	        $element .= ' class="' . $class . '"';
	    }
	    $element .= '>';	
	} else {
	    $element = '';
	}
	my $pattern = quotemeta('<span class="mt-enclosure');
	$text =~ s/$pattern.*?>(<.*?>)<\/span>/$element$1$closer/g;
	return $text;
}

sub _post_save_entry {
    my ($eh, $app, $obj, $original) = @_;
    my $text = $obj->text;
    my $more = $obj->text_more;
    my $org_text = $text;
    my $org_more = $more;
    $text =~ s/<div><br\s\/><\/div>//g;
    $more =~ s/<div><br\s\/><\/div>//g;
    $text =~ s/class="mt-image-none"\s//g;
    $more =~ s/class="mt-image-none"\s//g;  
    if ( ($text ne $org_text) || ($more ne $org_more) ) {
        $obj->text($text);
        $obj->text_more($more);
        $obj->save
            or return $app->trans_error('Error Saving Entry: [_1]', $obj->errstr);
    }
}

sub _edit_entry {
    my ($eh, $app, $tmpl) = @_;
    my $old = 'app.editor.textarea.focus();';
    my $q_old = quotemeta($old);
    my $new =<<TMPL;
// clean up for Firefox
        var target_obj = document.getElementById('editor-content-textarea');
        target_obj.style.display = "none";
        var val = target_obj.value;
        val = val.replace('<div><br /></div>', '');
        // clean up for new entry
        val = val.replace('class="mt-image-none" ', '');
        target_obj.value = val;
        target_obj.style.display = "block";
        // end clean up
        
TMPL
    $$tmpl =~ s/$q_old/$new$old/g;
}

sub _asset_options {
    my ($eh, $app, $tmpl) = @_;
    $$tmpl =~ s/method="post"/method="get"/;
}

sub _asset_options_image {
    my ($eh, $app, $tmpl) = @_;
    my $old = '<input type="radio"';
    my $q_old = quotemeta($old);
    my $new =<<TMPL;
    <label><input type="radio" name="align" id="align-none" class="rb" value="none"
    <mt:unless name="align_left"><mt:unless name="align_center"><mt:unless name="align_right">checked="checked"
    </mt:unless></mt:unless></mt:unless>/>
    <__trans phrase="None"></label>
    
TMPL
    $$tmpl =~ s/$q_old/$new$old/;
}

sub _asset_insert {
    my ($eh, $app, $tmpl) = @_;
    $$tmpl =<<TMPL;
<mt:include name="dialog/header.tmpl">
<script type="text/javascript">
<!--
var param = window.location.search;
var params = param.split('&align=');
params = params[1].split('&');
var align = params[0];
var tag = '<mt:var name="UPLOAD_HTML" escape="JS">';
if (align == 'none') {
    tag = tag.replace(/style=.*?>/, '/>');
    tag = tag.replace('class="mt-image-none" ', '');
}
window.parent.app.insertHTML( tag, '<mt:var name="EDIT_FIELD">' );
closeDialog();
//-->
</script>
<mt:include name="dialog/footer.tmpl">
TMPL
}

1;